@@ -27,6 +27,7 @@
 
 #include "common/spi-dbus.h"
 #include "object.h"
+#include "introspection.h"
 
 static dbus_bool_t
 impl_get_NRows (DBusMessageIter * iter, void *user_data)
@@ -94,6 +95,7 @@ impl_GetAccessibleAt (DBusConnection * bus, DBusMessage * message,
 {
   AtkTable *table = (AtkTable *) user_data;
   dbus_int32_t row, column;
+  DBusMessage *reply;
   DBusError error;
   AtkObject *obj;
 
@@ -107,7 +109,10 @@ impl_GetAccessibleAt (DBusConnection * bus, DBusMessage * message,
       return droute_invalid_arguments_error (message);
     }
   obj = atk_table_ref_at (table, row, column);
-  return spi_object_return_reference (message, obj);
+  reply = spi_object_return_reference (message, obj);
+  g_object_unref (obj);
+
+  return reply;
 }
 
 static DBusMessage *
@@ -351,7 +356,6 @@ impl_GetColumnHeader (DBusConnection * bus, DBusMessage * message,
       return droute_invalid_arguments_error (message);
     }
   obj = atk_table_get_column_header (table, column);
-  obj = atk_table_get_column_header (table, column);
   return spi_object_return_reference (message, obj);
 }
 
@@ -677,8 +681,8 @@ static DRouteProperty properties[] = {
   {impl_get_NColumns, NULL, "NColumns"},
   {impl_get_Caption, NULL, "Caption"},
   {impl_get_Summary, NULL, "Summary"},
-  {impl_get_NSelectedRows, NULL, "nSelectedRows"},
-  {impl_get_NSelectedColumns, NULL, "nSelectedColumns"},
+  {impl_get_NSelectedRows, NULL, "NSelectedRows"},
+  {impl_get_NSelectedColumns, NULL, "NSelectedColumns"},
   {NULL, NULL, NULL}
 };
 
@@ -686,5 +690,5 @@ void
 spi_initialize_table (DRoutePath * path)
 {
   droute_path_add_interface (path,
-                             SPI_DBUS_INTERFACE_TABLE, methods, properties);
+                             SPI_DBUS_INTERFACE_TABLE, spi_org_a11y_atspi_Table, methods, properties);
 };
